@@ -1,9 +1,11 @@
 """Collection of language-specific analyzers and analyzer registry for Annif"""
 
 import re
-from . import simple
-from . import snowball
+
 import annif
+from annif.util import parse_args
+
+from . import simple, simplemma, snowball
 
 _analyzers = {}
 
@@ -13,29 +15,34 @@ def register_analyzer(analyzer):
 
 
 def get_analyzer(analyzerspec):
-    match = re.match(r'(\w+)(\((.*)\))?', analyzerspec)
+    match = re.match(r"(\w+)(\((.*)\))?", analyzerspec)
     if match is None:
-        raise ValueError(
-            "Invalid analyzer specification {}".format(analyzerspec))
+        raise ValueError("Invalid analyzer specification {}".format(analyzerspec))
 
     analyzer = match.group(1)
+    posargs, kwargs = parse_args(match.group(3))
+    posargs = posargs if posargs else [None]
     try:
-        param = match.group(3)
-    except IndexError:
-        param = None
-
-    try:
-        return _analyzers[analyzer](param)
+        return _analyzers[analyzer](*posargs, **kwargs)
     except KeyError:
         raise ValueError("No such analyzer {}".format(analyzer))
 
 
 register_analyzer(simple.SimpleAnalyzer)
 register_analyzer(snowball.SnowballAnalyzer)
+register_analyzer(simplemma.SimplemmaAnalyzer)
 
 # Optional analyzers
 try:
     from . import voikko
+
     register_analyzer(voikko.VoikkoAnalyzer)
 except ImportError:
     annif.logger.debug("voikko not available, not enabling voikko analyzer")
+
+try:
+    from . import spacy
+
+    register_analyzer(spacy.SpacyAnalyzer)
+except ImportError:
+    annif.logger.debug("spaCy not available, not enabling spacy analyzer")
