@@ -6,8 +6,9 @@ from . import analyzer
 class SimpleAnalyzer(analyzer.Analyzer):
     name = "simple"
 
-    def __init__(self, param):
+    def __init__(self, param, **kwargs):
         self.param = param
+        super().__init__(**kwargs)
 
-    def normalize_word(self, word):
+    def _normalize_word(self, word):
         return word.lower()
