@@ -2,24 +2,38 @@
 and returns the results"""
 
 
+import importlib
+
 import dateutil.parser
 import requests
 import requests.exceptions
-from annif.suggestion import SubjectSuggestion, ListSuggestionResult
+
 from annif.exception import OperationFailedException
+from annif.suggestion import SubjectSuggestion
+
 from . import backend
 
 
 class HTTPBackend(backend.AnnifBackend):
     name = "http"
+    _headers = None
+
+    @property
+    def headers(self):
+        if self._headers is None:
+            version = importlib.metadata.version("annif")
+            self._headers = {
+                "User-Agent": f"Annif/{version}",
+            }
+        return self._headers
 
     @property
     def is_trained(self):
-        return self._get_project_info('is_trained')
+        return self._get_project_info("is_trained")
 
     @property
     def modification_time(self):
-        mtime = self._get_project_info('modification_time')
+        mtime = self._get_project_info("modification_time")
         if mtime is None:
             return None
         return dateutil.parser.parse(mtime)
@@ -27,7 +41,9 @@ class HTTPBackend(backend.AnnifBackend):
     def _get_project_info(self, key):
         params = self._get_backend_params(None)
         try:
-            req = requests.get(params['endpoint'].replace('/suggest', ''))
+            req = requests.get(
+                params["endpoint"].replace("/suggest", ""), headers=self.headers
+            )
             req.raise_for_status()
         except requests.exceptions.RequestException as err:
             msg = f"HTTP request failed: {err}"
@@ -44,38 +60,39 @@ class HTTPBackend(backend.AnnifBackend):
             return None
 
     def _suggest(self, text, params):
-        data = {'text': text}
-        if 'project' in params:
-            data['project'] = params['project']
+        data = {"text": text}
+        if "project" in params:
+            data["project"] = params["project"]
 
         try:
-            req = requests.post(params['endpoint'], data=data)
+            req = requests.post(params["endpoint"], data=data, headers=self.headers)
             req.raise_for_status()
         except requests.exceptions.RequestException as err:
             self.warning("HTTP request failed: {}".format(err))
-            return ListSuggestionResult([])
+            return []
 
         try:
             response = req.json()
         except ValueError as err:
             self.warning("JSON decode failed: {}".format(err))
-            return ListSuggestionResult([])
+            return []
 
-        if 'results' in response:
-            results = response['results']
+        if "results" in response:
+            results = response["results"]
         else:
             results = response
 
         try:
-            subject_suggestions = [SubjectSuggestion(
-                uri=hit['uri'],
-                label=None,
-                notation=None,
-                score=hit['score'])
-                for hit in results if hit['score'] > 0.0]
+            subject_suggestions = [
+                SubjectSuggestion(
+                    subject_id=self.project.subjects.by_uri(hit["uri"]),
+                    score=hit["score"],
+                )
+                for hit in results
+                if hit["score"] > 0.0
+            ]
         except (TypeError, ValueError) as err:
             self.warning("Problem interpreting JSON data: {}".format(err))
-            return ListSuggestionResult([])
+            return []
 
-        return ListSuggestionResult.create_from_index(subject_suggestions,
-                                                      self.project.subjects)
+        return subject_suggestions
