@@ -3,17 +3,18 @@
 
 import abc
 import os.path
+
 import joblib
 from sklearn.feature_extraction.text import TfidfVectorizer
+
 import annif.util
 from annif.exception import NotInitializedException
-from annif.suggestion import ListSuggestionResult
 
 
 class ChunkingBackend(metaclass=abc.ABCMeta):
     """Annif backend mixin that implements chunking of input"""
 
-    DEFAULT_PARAMETERS = {'chunksize': 1}
+    DEFAULT_PARAMETERS = {"chunksize": 1}
 
     def default_params(self):
         return self.DEFAULT_PARAMETERS
@@ -26,24 +27,25 @@ class ChunkingBackend(metaclass=abc.ABCMeta):
         pass  # pragma: no cover
 
     def _suggest(self, text, params):
-        self.debug('Suggesting subjects for text "{}..." (len={})'.format(
-            text[:20], len(text)))
+        self.debug(
+            'Suggesting subjects for text "{}..." (len={})'.format(text[:20], len(text))
+        )
         sentences = self.project.analyzer.tokenize_sentences(text)
-        self.debug('Found {} sentences'.format(len(sentences)))
-        chunksize = int(params['chunksize'])
+        self.debug("Found {} sentences".format(len(sentences)))
+        chunksize = int(params["chunksize"])
         chunktexts = []
         for i in range(0, len(sentences), chunksize):
-            chunktexts.append(' '.join(sentences[i:i + chunksize]))
-        self.debug('Split sentences into {} chunks'.format(len(chunktexts)))
+            chunktexts.append(" ".join(sentences[i : i + chunksize]))
+        self.debug("Split sentences into {} chunks".format(len(chunktexts)))
         if len(chunktexts) == 0:  # no input, empty result
-            return ListSuggestionResult([])
+            return []
         return self._suggest_chunks(chunktexts, params)
 
 
 class TfidfVectorizerMixin:
     """Annif backend mixin that implements TfidfVectorizer functionality"""
 
-    VECTORIZER_FILE = 'vectorizer'
+    VECTORIZER_FILE = "vectorizer"
 
     vectorizer = None
 
@@ -51,20 +53,19 @@ class TfidfVectorizerMixin:
         if self.vectorizer is None:
             path = os.path.join(self.datadir, self.VECTORIZER_FILE)
             if os.path.exists(path):
-                self.debug('loading vectorizer from {}'.format(path))
+                self.debug("loading vectorizer from {}".format(path))
                 self.vectorizer = joblib.load(path)
             else:
                 raise NotInitializedException(
                     "vectorizer file '{}' not found".format(path),
-                    backend_id=self.backend_id)
+                    backend_id=self.backend_id,
+                )
 
     def create_vectorizer(self, input, params={}):
-        self.info('creating vectorizer')
+        self.info("creating vectorizer")
         self.vectorizer = TfidfVectorizer(**params)
         veccorpus = self.vectorizer.fit_transform(input)
         annif.util.atomic_save(
-            self.vectorizer,
-            self.datadir,
-            self.VECTORIZER_FILE,
-            method=joblib.dump)
+            self.vectorizer, self.datadir, self.VECTORIZER_FILE, method=joblib.dump
+        )
         return veccorpus
