@@ -11,8 +11,8 @@ import os
 class Config(object):
     DEBUG = False
     TESTING = False
-    PROJECTS_FILE = os.environ.get('ANNIF_PROJECTS', default='projects.cfg')
-    DATADIR = os.environ.get('ANNIF_DATADIR', default='data')
+    PROJECTS_CONFIG_PATH = os.environ.get("ANNIF_PROJECTS", default="")
+    DATADIR = os.environ.get("ANNIF_DATADIR", default="data")
     INITIALIZE_PROJECTS = False
 
 
@@ -26,8 +26,8 @@ class DevelopmentConfig(Config):
 
 class TestingConfig(Config):
     TESTING = True
-    PROJECTS_FILE = 'tests/projects.cfg'
-    DATADIR = 'tests/data'
+    PROJECTS_CONFIG_PATH = "tests/projects.cfg"
+    DATADIR = "tests/data"
 
 
 class TestingInitializeConfig(TestingConfig):
@@ -35,8 +35,16 @@ class TestingInitializeConfig(TestingConfig):
 
 
 class TestingNoProjectsConfig(TestingConfig):
-    PROJECTS_FILE = 'tests/notfound.cfg'
+    PROJECTS_CONFIG_PATH = "tests/notfound.cfg"
 
 
 class TestingInvalidProjectsConfig(TestingConfig):
-    PROJECTS_FILE = 'tests/projects_invalid.cfg'
+    PROJECTS_CONFIG_PATH = "tests/projects_invalid.cfg"
+
+
+class TestingTOMLConfig(TestingConfig):
+    PROJECTS_CONFIG_PATH = "tests/projects.toml"
+
+
+class TestingDirectoryConfig(TestingConfig):
+    PROJECTS_CONFIG_PATH = "tests/projects.d"
